Fonduer
=======

|Travis| |Coveralls| |ReadTheDocs| |GitHubIssues| |PyPI| |PyPIVersion| |GitHubStars| |License|

Fonduer is a framework for building knowledge base construction (KBC)
applications from *richy formatted data* and is implemented as a library on top
of a modified version of Snorkel_.

*Note that Fonduer is still actively under development, so feedback and
contributions are welcome. Let us know in the Issues_ section or feel free to
submit your contributions as a pull request.*

Reference
---------

`Fonduer: Knowledge Base Construction from Richly Formatted
Data <https://arxiv.org/abs/1703.05028>`__::

    @article{wu2017fonduer,
      title={Fonduer: Knowledge Base Construction from Richly Formatted Data},
      author={Wu, Sen and Hsiao, Luke and Cheng, Xiao and Hancock, Braden and Rekatsinas, Theodoros and Levis, Philip and R{\'e}, Christopher},
      journal={arXiv preprint arXiv:1703.05028},
      year={2017}
    }

Installation
------------

Check out our `Getting Started Guide`_ to get up and running.

Learning how to use ``Fonduer``
-------------------------------

The `Fonduer tutorials`_ cover the Fonduer workflow, showing how to extract
relations from hardware datasheets and scientific literature.

.. |Travis| image:: https://img.shields.io/travis/HazyResearch/fonduer.svg
   :target: https://travis-ci.org/HazyResearch/fonduer
.. |Coveralls| image:: https://img.shields.io/coveralls/github/HazyResearch/fonduer.svg
   :target: https://coveralls.io/github/HazyResearch/fonduer
.. |ReadTheDocs| image:: https://img.shields.io/readthedocs/fonduer.svg
   :target: https://fonduer.readthedocs.io/
.. |GitHubIssues| image:: https://img.shields.io/github/issues/HazyResearch/fonduer.svg
   :target: https://github.com/HazyResearch/fonduer/issues
.. |PyPI| image:: https://img.shields.io/pypi/v/fonduer.svg
   :target: https://pypi.org/project/fonduer/
.. |PyPIVersion| image:: https://img.shields.io/pypi/pyversions/fonduer.svg
   :target: https://pypi.org/project/fonduer/
.. |GitHubStars| image:: https://img.shields.io/github/stars/HazyResearch/fonduer.svg
   :target: https://github.com/HazyResearch/fonduer/stargazers
.. |License| image:: https://img.shields.io/github/license/HazyResearch/fonduer.svg
   :target: https://github.com/HazyResearch/fonduer/blob/master/LICENSE

.. _Snorkel: https://hazyresearch.github.io/snorkel/
.. _Issues: https://github.com/HazyResearch/fonduer/issues
.. _Getting Started Guide: https://fonduer.readthedocs.io/en/latest/user/getting_started.html
.. _Fonduer tutorials: https://github.com/hazyresearch/fonduer-tutorials
